==> bitmovin-analytics-2.13.0.tgz: package/tests/adapters/Bitmovin7Adapter.tests.ts <==
import {logger} from '../../js/utils/Logger';
import {Bitmovin7Adapter} from '../../js/adapters/Bitmovin7Adapter';

const spy = jest.spyOn(logger, 'errorMessageToUser').mockImplementation(() => {});

describe('augment', () => {
  beforeEach(() => {
    (spy as any).mockClear();
  });

  it('assigns does not throw exception at all', () => {
    const player = {};
    try {
      new Bitmovin7Adapter(player, undefined);
      new Bitmovin7Adapter(player, undefined);
    } catch (e) {
      expect(true).toBe(false);
    }
  });
  it('should write to error console if player already contains another .analytics object', () => {
    const player = {};
    new Bitmovin7Adapter(player, undefined);
    new Bitmovin7Adapter(player, undefined);
    expect(logger.errorMessageToUser).toBeCalledWith('Bitmovin Analytics is already hooked up to this player instance')
    expect(logger.errorMessageToUser).toBeCalledTimes(1);
  });
  it('should not wrap setup a second time on player instance', () => {
    const player = {};
    new Bitmovin7Adapter(player, undefined);
    const old = (player as any).setup;
    new Bitmovin7Adapter(player, undefined);
    expect(old).toEqual((player as any).setup);

  });
  it('should write on each n+1 invocation to console error', () => {
    const player = {};
    new Bitmovin7Adapter(player, undefined);
    new Bitmovin7Adapter(player, undefined);
    new Bitmovin7Adapter(player, undefined);
    expect(logger.errorMessageToUser).toBeCalledTimes(2);
  });
});

==> bitmovin-analytics-2.19.0.tgz: package/tests/adapters/Bitmovin7Adapter.tests.ts <==
import {Bitmovin7Adapter} from '../../js/adapters/Bitmovin7Adapter';
import {logger} from '../../js/utils/Logger';

const spy = jest.spyOn(logger, 'errorMessageToUser').mockImplementation(() => {});

describe('augment', () => {
  beforeEach(() => {
    (spy as any).mockClear();
  });

  it('assigns does not throw exception at all', () => {
    const player = {};
    try {
      new Bitmovin7Adapter(player, undefined);
      new Bitmovin7Adapter(player, undefined);
    } catch (e) {
      expect(true).toBe(false);
    }
  });
  it('should write to error console if player already contains another .analytics object', () => {
    const player = {};
    new Bitmovin7Adapter(player, undefined);
    new Bitmovin7Adapter(player, undefined);
    expect(logger.errorMessageToUser).toBeCalledWith('Bitmovin Analytics is already hooked up to this player instance');
    expect(logger.errorMessageToUser).toBeCalledTimes(1);
  });
  it('should not wrap setup a second time on player instance', () => {
    const player = {};
    new Bitmovin7Adapter(player, undefined);
    const old = (player as any).setup;
    new Bitmovin7Adapter(player, undefined);
    expect(old).toEqual((player as any).setup);
  });
  it('should write on each n+1 invocation to console error', () => {
    const player = {};
    new Bitmovin7Adapter(player, undefined);
    new Bitmovin7Adapter(player, undefined);
    new Bitmovin7Adapter(player, undefined);
    expect(logger.errorMessageToUser).toBeCalledTimes(2);
  });
});
